summaryrefslogtreecommitdiffstats
path: root/BaseTools/Source/C/Split/Split.c
diff options
context:
space:
mode:
authorGary Lin <glin@suse.com>2016-10-19 15:01:07 +0800
committerYonghong Zhu <yonghong.zhu@intel.com>2016-10-20 11:18:27 +0800
commit99e55970ff0778ad46177a9c0fafb0766d4e6837 (patch)
treea23fa791536674301c98e6b15f1f66e56e3cf309 /BaseTools/Source/C/Split/Split.c
parentf17c0ab617c86210d1b3de4ec493ee2f2ed3e1e6 (diff)
downloadedk2-99e55970ff0778ad46177a9c0fafb0766d4e6837.tar.gz
edk2-99e55970ff0778ad46177a9c0fafb0766d4e6837.tar.bz2
edk2-99e55970ff0778ad46177a9c0fafb0766d4e6837.zip
BaseTools: Fix typos in comments and variables
- Pacakge -> Package - outputed -> outputted - successull -> successfully - Libary -> Library - Pointion -> Position - paramter -> parameter Cc: Yonghong Zhu <yonghong.zhu@intel.com> Cc: Liming Gao <liming.gao@intel.com> Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Gary Lin <glin@suse.com> Reviewed-by: Liming Gao <liming.gao@intel.com> Reviewed-by: Yonghong Zhu <yonghong.zhu@intel.com>
Diffstat (limited to 'BaseTools/Source/C/Split/Split.c')
-rw-r--r--BaseTools/Source/C/Split/Split.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/BaseTools/Source/C/Split/Split.c b/BaseTools/Source/C/Split/Split.c
index c6f547ca43..d723ed0a94 100644
--- a/BaseTools/Source/C/Split/Split.c
+++ b/BaseTools/Source/C/Split/Split.c
@@ -323,7 +323,7 @@ Returns:
if (strlen(argv[0]) > 2) {
Status = CountVerboseLevel (&argv[0][2], strlen(argv[0]) - 2, &VerboseLevel);
if (EFI_ERROR (Status)) {
- Error (NULL, 0, 0x1003, NULL, "%s is invaild paramter!", argv[0]);
+ Error (NULL, 0, 0x1003, NULL, "%s is invaild parameter!", argv[0]);
return STATUS_ERROR;
}
}
@@ -344,9 +344,9 @@ Returns:
continue;
}
//
// Don't recognize the paramter.
//
- Error (NULL, 0, 0x1003, NULL, "%s is invaild paramter!", argv[0]);
+ Error (NULL, 0, 0x1003, NULL, "%s is invaild parameter!", argv[0]);
return STATUS_ERROR;
}
@@ -344,9 +344,9 @@ Returns:
}
//
- // Don't recognize the paramter.
+ // Don't recognize the parameter.
//